@@ -3,16 +3,12 @@ echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
 echo "" 												>> $EXTENSION/build_order.txt
 	
 # Required
-[[ $(command -v g-ir-compiler) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
+[[ $(command -v gi-inspect-typelib) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
 [ ! -f /lib/libgudev-1.0.so ] && echo "Installing libgudev" && extension --install libgudev && echo "Finished libgudev"
 # Recommended
 if [[ $INSTALL_RECOMMENDED != false ]]; then 
 	[[ $(command -v mbimcli) == "" ]] && echo "Installing libmbim" && extension --install libmbim && echo "Finished libmbim"
 fi
-# Optional
-if [[ $INSTALL_OPTIONAL != false ]]; then 
-	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
-fi
 
 if [ $BUILD_ALL == "false" ] && [[ $(command -v qmicli) == "" ]]; then
 	echo "libqmi" 										>> $EXTENSION/build_order.txt
